@@ -102,7 +102,7 @@ class SmartSeeds3D(object):
 
 
 
-     def __init__(self, BaseDir, NPZfilename, model_name, model_dir, n_patches_per_image, DownsampleFactor = 1, backbone = 'resnet', CroppedLoad = False, TrainUNET = True, TrainSTAR = True, GenerateNPZ = True, validation_split = 0.01, erosion_iterations = 0, copy_model_dir = None, PatchX=256, PatchY=256, PatchZ = 16, gridX = 1, gridY = 1, annisotropy = (1,1,1),  use_gpu = True,  batch_size = 4, depth = 3, kern_size = 3, startfilter = 48, n_rays = 16, epochs = 400, learning_rate = 0.0001):
+     def __init__(self, BaseDir, NPZfilename, model_name, model_dir, n_patches_per_image, DownsampleFactor = 1, backbone = 'resnet', CroppedLoad = False, TrainUNET = True, TrainSTAR = True, GenerateNPZ = True, validation_split = 0.01, erosion_iterations = 1, copy_model_dir = None, PatchX=256, PatchY=256, PatchZ = 16, gridX = 1, gridY = 1, annisotropy = (1,1,1),  use_gpu = True,  batch_size = 4, depth = 3, kern_size = 3, startfilter = 48, n_rays = 16, epochs = 400, learning_rate = 0.0001):
 
          
          
@@ -245,7 +245,7 @@ class SmartSeeds3D(object):
                             print('Training UNET model')
                             load_path = self.BaseDir + self.NPZfilename + '.npz'
         
-                            (X,Y), (X_val,Y_val), axes = load_training_data(load_path, validation_split=0.01, verbose=True)
+                            (X,Y), (X_val,Y_val), axes = load_training_data(load_path, self.validation_split=0.01, verbose=True)
                             c = axes_dict(axes)['C']
                             n_channel_in, n_channel_out = X.shape[c], Y.shape[c]
                             
