@@ -53,19 +53,18 @@ Boxname = 'ImageIDBox'
 
 class SegCorrect(object):
 
-     def __init__(self, imagedir, segmentationdir, fileextension = '*tif'):
+     def __init__(self, imagedir, segmentationdir):
          
          self.imagedir = imagedir
-         self.fileextension = fileextension
          self.segmentationdir = segmentationdir
          
      def showNapari(self):
                  
                  self.viewer = napari.Viewer()
-                 Raw_path = os.path.join(self.imagedir, self.fileextension)
+                 Raw_path = os.path.join(self.imagedir, '*tif')
                  X = glob.glob(Raw_path)
                  Imageids = []
-                 Seg_path = os.path.join(self.segmentationdir, self.fileextension)
+                 Seg_path = os.path.join(self.segmentationdir, '*tif')
                  Y = glob.glob(Seg_path)
                  SegImageids = []
                  for imagename in X:
@@ -88,7 +87,7 @@ class SegCorrect(object):
                  lambda trackid = imageidbox: self.image_add(
                          
                          imageidbox.currentText(),
-                         self.segmentationdir + "/" + os.path.basename(os.path.splitext(imageidbox.currentText())[0]),
+                         self.segmentationdir + "/" + os.path.basename(os.path.splitext(imageidbox.currentText())[0]) + '.tif',
                          os.path.basename(os.path.splitext(imageidbox.currentText())[0]),
                          False
                     
@@ -99,7 +98,7 @@ class SegCorrect(object):
                  lambda trackid = imageidbox: self.image_add(
                          
                          imageidbox.currentText(),
-                         self.segmentationdir + "/" + os.path.basename(os.path.splitext(imageidbox.currentText())[0]),
+                         self.segmentationdir + "/" + os.path.basename(os.path.splitext(imageidbox.currentText())[0]) + '.tif',
                          os.path.basename(os.path.splitext(imageidbox.currentText())[0]),
                          True
                     
